@@ -6,5 +6,5 @@ class AbstractPathBuilder:
     def create_path_builder(self, *args, **kwargs):
         raise NotImplementedError  # pragma: no cover
 
-    def tranform_attribute_name(self, name):
+    def transform_attribute_name(self, name):
         raise NotImplementedError  # pragma: no cover
