@@ -1,10 +1,9 @@
-from typing import Union
-
 from treepath.path.traverser.nested_match_traverser import NestedMatchTraverser
+from treepath.path.typing.json_types import JsonTypes
 
 
 class NestedValueTraverser(NestedMatchTraverser):
     __slots__ = ()
 
-    def __next__(self) -> Union[dict, list, str, int, float, bool, None]:
+    def __next__(self) -> JsonTypes:
         return super().__next__().data
